==> xdelta3-gui_24.3.tar.xz: BUILD/translations/xdelta3-gui_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Create delta</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file
----------
start process</extracomment>
        <translation>Delta oluştur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Create a binary difference between two files</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file</extracomment>
        <translation>İki dosya arasında ikili fark dosyası oluştur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Options</source>
        <extracomment>program options</extracomment>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Higher number = better compression ratio, but takes more time to finish</source>
        <translation>Daha yüksek sayı = daha iyi sıkıştırma oranı, ancak daha fazla zaman alır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Compression level</source>
        <extracomment>level of compression the delta file will use</extracomment>
        <translation>Sıkıştırma düzeyi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>More compression using various compression algorithms</source>
        <translation>Çeşitli sıkıştırma algoritmalarını kullanarak daha fazla sıkıştırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Secondary compression</source>
        <extracomment>an extra layer of compression</extracomment>
        <translation>İkincil sıkıştırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="241"/>
        <source>File selection</source>
        <extracomment>area for selecting input and output files</extracomment>
        <translation>Dosya seçimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>select target (new) file</source>
        <extracomment>select the new file from which to create a delta between it and the source.</extracomment>
        <translation>hedef (yeni) dosyayı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Target file</source>
        <translation>Hedef dosya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Source file</source>
        <translation>Kaynak dosya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Delta file name</source>
        <translation>Delta dosya adı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Select source file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Kaynak dosyayı seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>select source (old) file</source>
        <extracomment>select the original or source file</extracomment>
        <translation>kaynak (eski) dosyayı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Select target file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Hedef dosyayı seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Change location...</source>
        <extracomment>starts a file chooser to select destination for output delta file</extracomment>
        <translation>Konumu değiştir...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Apply delta</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file
----------
start the process</extracomment>
        <translation>Deltayı uygula</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Create a new file applying a delta (difference) file to an original file</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file</extracomment>
        <translation>Orijinal dosyaya delta (fark) dosyası uygulayarak yeni bir dosya oluştur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Input file</source>
        <extracomment>a file to start with as the source or input</extracomment>
        <translation>Girdi dosyası</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>select input file</source>
        <extracomment>select the input or older file</extracomment>
        <translation>girdi dosyası seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Select input file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Girdi dosyası seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Delta file</source>
        <extracomment>the delta or diff file between the input and the output</extracomment>
        <translation>Delta dosyası</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>select delta</source>
        <extracomment>select the delta or patch file</extracomment>
        <translation>deltayı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Select delta...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Deltayı Seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Output file</source>
        <extracomment>the final patched output file</extracomment>
        <translation>Çıktı dosyası</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>use default, or set up a custom name</source>
        <extracomment>create the new file name</extracomment>
        <translation>varsayılanı kullan veya özel bir ad belirle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Change location..</source>
        <extracomment>starts a file chooser to select destination for output file</extracomment>
        <translation>Konumu değiştir..</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>ISO Files (*.iso);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO Dosyaları (*.iso);;Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>ISO Files (*.xdelta3);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO Dosyaları (*.xdelta3);;Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Select file</source>
        <comment>choose a file</comment>
        <translation>Dosya seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="123"/>
        <source>Select directory to place the file in</source>
        <comment>select a target directory</comment>
        <translation>Dosyanın yerleştirileceği dizini seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Path not found</source>
        <comment>warning about not finding the target directory</comment>
        <translation>Yol bulunamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Please select directory again.</source>
        <comment>message to try again</comment>
        <translation>Please select directory again.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Please enter a name for the output file.</source>
        <translation>Lütfen çıktı dosyası için bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>File exists</source>
        <translation>Dosya mevcut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Output file exists, do you want to overwrite?</source>
        <comment>warning about overwritting an existing file</comment>
        <translation>Çıktı dosyası mevcut, üzerine yazmak ister misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Success</source>
        <comment>information that file was successfully written</comment>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>File was successfuly written to &apos;%1&apos; directory.</source>
        <comment>information that file was successfully written</comment>
        <translation>Dosya başarıyla &apos;%1&apos; dizinine yazıldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Took %1 to patch the file.</source>
        <comment>elapsed time, leave %1 untranslated</comment>
        <translation>Dosyaya yama uygulamak %1 sürdü.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Error: Could not write the file.</source>
        <comment>information that there was an error creating the file</comment>
        <translation>Hata: Dosya yazılamadı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Please enter a name for the delta file.</source>
        <comment>name of delta file being created</comment>
        <translation>Lütfen delta dosyası için bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>File not found</source>
        <comment>warning about file not found</comment>
        <translation>Dosya bulunamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>File &apos;%1&apos; found or not a file, please double-check the input.</source>
        <comment>warning about file not found</comment>
        <translation>&apos;%1&apos; dosyası bulunamadı veya dosya değil, lütfen girişi tekrar kontrol edin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>File exists</source>
        <comment>warning about overwritting file</comment>
        <translation>Dosya mevcut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Delta file exists, do you want to overwrite?</source>
        <comment>warning about overwritting file</comment>
        <translation>Delta dosyası mevcut, üzerine yazmak istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Success</source>
        <comment>information on file written succesfully</comment>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>File &apos;%1&apos; was successfuly written.</source>
        <comment>information on file written succesfully</comment>
        <translation>&apos;%1&apos; dosyası başarıyla yazıldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Took %1 to create the patch.</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>Yamayı oluşturmak %1 aldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Error: Could not write the file.</source>
        <comment>information that file was not written succsessfully</comment>
        <translation>Hata: Dosya yazılamadı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Cancel</source>
        <comment>stop an action in progress</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>%1 elapsed</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>%1 geçti</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>GUI for xdelta3 application.</source>
        <comment>short description for --help and desktop file</comment>
        <translation>Xdelta3 uygulaması için arayüz.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>App for generating a binary difference between two files in the form of delta encoding</source>
        <comment>extra description for --help</comment>
        <translation>İki dosya arasında delta kodlaması biçiminde ikili fark oluşturmaya yönelik uygulama</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>file</source>
        <translation>dosya</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Name of the delta file</source>
        <translation>Delta dosyasının adı</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>[file]</source>
        <translation>[dosya]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program as normal user.</source>
        <comment>warning about running application as root</comment>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>

==> xdelta3-gui_26.01.3.tar.xz: BUILD/translations/xdelta3-gui_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Create delta</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file
----------
start process</extracomment>
        <translation>Delta oluştur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Create a binary difference between two files</source>
        <extracomment>meaning to create a delta file that bridges between the source and target file</extracomment>
        <translation>İki dosya arasında ikili fark dosyası oluştur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Options</source>
        <extracomment>program options</extracomment>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Higher number = better compression ratio, but takes more time to finish</source>
        <translation>Daha yüksek sayı = daha iyi sıkıştırma oranı, ancak daha fazla zaman alır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Compression level</source>
        <extracomment>level of compression the delta file will use</extracomment>
        <translation>Sıkıştırma düzeyi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>More compression using various compression algorithms</source>
        <translation>Çeşitli sıkıştırma algoritmalarını kullanarak daha fazla sıkıştırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Secondary compression</source>
        <extracomment>an extra layer of compression</extracomment>
        <translation>İkincil sıkıştırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.ui" line="241"/>
        <source>File selection</source>
        <extracomment>area for selecting input and output files</extracomment>
        <translation>Dosya seçimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>select target (new) file</source>
        <extracomment>select the new file from which to create a delta between it and the source.</extracomment>
        <translation>hedef (yeni) dosyayı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Target file</source>
        <translation>Hedef dosya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <source>Source file</source>
        <translation>Kaynak dosya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>Delta file name</source>
        <translation>Delta dosya adı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Select source file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Kaynak dosyayı seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>select source (old) file</source>
        <extracomment>select the original or source file</extracomment>
        <translation>kaynak (eski) dosyayı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Select target file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Hedef dosyayı seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Change location...</source>
        <extracomment>starts a file chooser to select destination for output delta file</extracomment>
        <translation>Konumu değiştir...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Apply delta</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file
----------
start the process</extracomment>
        <translation>Deltayı uygula</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Create a new file applying a delta (difference) file to an original file</source>
        <extracomment>meaning to apply a delta file to a input file to create a new output file</extracomment>
        <translation>Orijinal dosyaya delta (fark) dosyası uygulayarak yeni bir dosya oluştur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Input file</source>
        <extracomment>a file to start with as the source or input</extracomment>
        <translation>Girdi dosyası</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>select input file</source>
        <extracomment>select the input or older file</extracomment>
        <translation>girdi dosyası seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Select input file...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Girdi dosyası seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Delta file</source>
        <extracomment>the delta or diff file between the input and the output</extracomment>
        <translation>Delta dosyası</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>select delta</source>
        <extracomment>select the delta or patch file</extracomment>
        <translation>deltayı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Select delta...</source>
        <extracomment>starts a file chooser to select a file</extracomment>
        <translation>Deltayı Seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Output file</source>
        <extracomment>the final patched output file</extracomment>
        <translation>Çıktı dosyası</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>use default, or set up a custom name</source>
        <extracomment>create the new file name</extracomment>
        <translation>varsayılanı kullan veya özel bir ad belirle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Change location..</source>
        <extracomment>starts a file chooser to select destination for output file</extracomment>
        <translation>Konumu değiştir..</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>ISO Files (*.iso);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO Dosyaları (*.iso);;Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>ISO Files (*.xdelta3);;All Files (*)</source>
        <comment>kinds of files to choose</comment>
        <translation>ISO Dosyaları (*.xdelta3);;Tüm Dosyalar (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Select file</source>
        <comment>choose a file</comment>
        <translation>Dosya seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="123"/>
        <source>Select directory to place the file in</source>
        <comment>select a target directory</comment>
        <translation>Dosyanın yerleştirileceği dizini seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Path not found</source>
        <comment>warning about not finding the target directory</comment>
        <translation>Yol bulunamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Please select directory again.</source>
        <comment>message to try again</comment>
        <translation>Please select directory again.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Please enter a name for the output file.</source>
        <translation>Lütfen çıktı dosyası için bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>File exists</source>
        <translation>Dosya mevcut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Output file exists, do you want to overwrite?</source>
        <comment>warning about overwritting an existing file</comment>
        <translation>Çıktı dosyası mevcut, üzerine yazmak ister misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Success</source>
        <comment>information that file was successfully written</comment>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>File was successfuly written to &apos;%1&apos; directory.</source>
        <comment>information that file was successfully written</comment>
        <translation>Dosya başarıyla &apos;%1&apos; dizinine yazıldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Took %1 to patch the file.</source>
        <comment>elapsed time, leave %1 untranslated</comment>
        <translation>Dosyaya yama uygulamak %1 sürdü.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Error: Could not write the file.</source>
        <comment>information that there was an error creating the file</comment>
        <translation>Hata: Dosya yazılamadı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Please enter a name for the delta file.</source>
        <comment>name of delta file being created</comment>
        <translation>Lütfen delta dosyası için bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>File not found</source>
        <comment>warning about file not found</comment>
        <translation>Dosya bulunamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>File &apos;%1&apos; found or not a file, please double-check the input.</source>
        <comment>warning about file not found</comment>
        <translation>&apos;%1&apos; dosyası bulunamadı veya dosya değil, lütfen girişi tekrar kontrol edin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>File exists</source>
        <comment>warning about overwritting file</comment>
        <translation>Dosya mevcut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Delta file exists, do you want to overwrite?</source>
        <comment>warning about overwritting file</comment>
        <translation>Delta dosyası mevcut, üzerine yazmak istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Success</source>
        <comment>information on file written succesfully</comment>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>File &apos;%1&apos; was successfuly written.</source>
        <comment>information on file written succesfully</comment>
        <translation>&apos;%1&apos; dosyası başarıyla yazıldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Took %1 to create the patch.</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>Yamayı oluşturmak %1 aldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Error: Could not write the file.</source>
        <comment>information that file was not written succsessfully</comment>
        <translation>Hata: Dosya yazılamadı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Cancel</source>
        <comment>stop an action in progress</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>%1 elapsed</source>
        <comment>elasped time, leave %1 untranslated</comment>
        <translation>%1 geçti</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>GUI for xdelta3 application.</source>
        <comment>short description for --help and desktop file</comment>
        <translation>Xdelta3 uygulaması için arayüz.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>App for generating a binary difference between two files in the form of delta encoding</source>
        <comment>extra description for --help</comment>
        <translation>İki dosya arasında delta kodlaması biçiminde ikili fark oluşturmaya yönelik uygulama</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>file</source>
        <translation>dosya</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Name of the delta file</source>
        <translation>Delta dosyasının adı</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>[file]</source>
        <translation>[dosya]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program as normal user.</source>
        <comment>warning about running application as root</comment>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
